==> kxmleditor-0.7.2.tar.gz: kxmleditor-0.7.2/part/kxmleditorabout.h <==
/***************************************************************************
                          kxmleditorabout.h  -  description
                             -------------------
    begin                : Mon Sep 24 2001
    copyright            : (C) 2001 by The KXMLEditor Team
    email                : OleBowle@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KXMLEDITORABOUT_H
#define KXMLEDITORABOUT_H

#include <kaboutdata.h>
#include <klocale.h>

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

static const char *description = I18N_NOOP("KXML Editor is an utility to display and edit XML files");

class KXMLEditorAboutData : public KAboutData
{
	public:
		KXMLEditorAboutData()
		 : KAboutData( "kxmleditor",
		               I18N_NOOP("KXML Editor"),
		               VERSION,
		               description,
		               KAboutData::License_GPL,
		               "(c) 2001, The KXML Editor Developers",
		               0,
		               "http://kxmleditor.sourceforge.net",
		               "lvanek@eanet.cz" )
		{
			addAuthor("Lumir Vanek", I18N_NOOP("Main developer and maintainer"), "lvanek@eanet.cz");
			addAuthor("Olaf Hartig", I18N_NOOP("KParts code, XML tree inplace editing, many bug fixes, useful ideas"), "hartig@users.sourceforge.net");
			addAuthor("Mateusz Korniak", I18N_NOOP("DCOP code"), "matkor@users.sourceforge.net");
		}
};

#endif

==> kxmleditor_1.0.0.orig.tar.gz: kxmleditor-1.0.0/part/kxmleditorabout.h <==
/***************************************************************************
                          kxmleditorabout.h  -  description
                             -------------------
    begin                : Mon Sep 24 2001
    copyright            : (C) 2001, 2002, 2003 by The KXMLEditor Team
    email                : OleBowle@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KXMLEDITORABOUT_H
#define KXMLEDITORABOUT_H

#include <kaboutdata.h>
#include <klocale.h>

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

static const char *description = I18N_NOOP("KXML Editor is an utility to display and edit XML files");

class KXMLEditorAboutData : public KAboutData
{
	public:
		KXMLEditorAboutData()
		 : KAboutData( "kxmleditor",
		               I18N_NOOP("KXML Editor"),
		               VERSION,
		               description,
		               KAboutData::License_GPL,
		               "(c) 2001-2004, The KXML Editor Developers",
		               0,
		               "http://kxmleditor.sourceforge.net",
		               "lvanek@users.sourceforge.net" )
		{
			addAuthor("Lumir Vanek", I18N_NOOP("Developer and maintainer"), "lvanek@users.sourceforge.net");
			addAuthor("Olaf Hartig", I18N_NOOP("Developer"), "hartig@users.sourceforge.net");
			//addAuthor("Mateusz Korniak", I18N_NOOP("DCOP code"), "matkor@users.sourceforge.net");
      addAuthor("Adam Charytoniuk", I18N_NOOP("Developer"), "a_charytoniuk@users.sourceforge.net");
    }
};

#endif
